//---------------------------------------------------------------------------
// Copyright 2000 Andreas Huennebeck
//
// Licensed under the terms of the GNU General Public License.
// ABSOLUTELY NO WARRANTY. See the file `COPYING' in this distribution.
//
// $Source: /home/ah/CvsTree/daten/src/include/AH/Error/Intern.h,v $
// $Id: Intern.h,v 1.4 2004/04/20 22:27:08 ah Exp $
//
// Description: 
//
//---------------------------------------------------------------------------

#ifndef AH_ERROR_INTERN_H		// prevent multiple includes
#define AH_ERROR_INTERN_H

// --- forward declarations ---

// --- necessary includes ---

#include <AH/Error/Basic.h>
#include <cerrno>		// to know errno
#include <string>		// to know strerror

// --- types and classes ---

BEGIN_NAMESPACE(AH)

/// class for internal errors (caused by the programmer)
/**
   {\tt ErrorIntern} is used for all internal programming errors.

   Please include {\em Error/Intern.h}.
*/
class ErrorIntern: public ErrorBasic
{
  public:
    /// default constructor
    ErrorIntern()
	: ErrorBasic("internal error") {}
    /// constructor
    ErrorIntern(const string& m)
	: ErrorBasic(m) {}
    /// copy constructor
    ErrorIntern(const ErrorIntern& src)
	: ErrorBasic(src) {}
    /// assignment operator:
    const ErrorIntern& operator=(const ErrorIntern &src)
	{
	    if (&src != this)
	    {
		ErrorBasic::operator=(src);
	    }
	    return *this;
	}
    /// destructor:
    virtual ~ErrorIntern () throw () {}

};


// common internal errors:
/// bad argument
/**
   {\tt ErrorInternBadArg} is used when an argument is bad or invalid.

   Please include {\em Error/Intern.h}.
*/
class ErrorInternBadArg: public ErrorIntern
{
  public:
    /// default constructor
    ErrorInternBadArg()
	: ErrorIntern("bad argument") {}
    /// constructor
    ErrorInternBadArg(const string& m)
	: ErrorIntern("bad argument: " + m) {}
    /// copy constructor
    ErrorInternBadArg(const ErrorIntern& src)
	: ErrorIntern(src) {}
    /// assignment operator:
    const ErrorInternBadArg& operator=(const ErrorInternBadArg &src)
	{ if (&src != this) ErrorIntern::operator=(src); return *this; }
    /// destructor:
    virtual ~ErrorInternBadArg () throw () {}
};


/// argument is NULL pointer
/**
   {\tt ErrorInternNullPtrArg} is used when an argument is a NULL pointer.

   Please include {\em Error/Intern.h}.
*/
class ErrorInternNullPtrArg: public ErrorIntern
{
  public:
    /// default constructor
    ErrorInternNullPtrArg()
	: ErrorIntern("NULL pointer argument") {}
    /// constructor
    ErrorInternNullPtrArg(const string& m)
	: ErrorIntern("NULL pointer argument" + m) {}
    /// copy constructor
    ErrorInternNullPtrArg(const ErrorIntern& src)
	: ErrorIntern(src) {}
    /// assignment operator:
    const ErrorInternNullPtrArg& operator=(const ErrorInternNullPtrArg &src)
	{ if (&src != this) ErrorIntern::operator=(src); return *this; }
    /// destructor:
    virtual ~ErrorInternNullPtrArg () throw () {}
};


/// not yet implemented
/**
   {\tt ErrorInternNotYetImpl} is used when a feature is not implemented.

   Please include {\em Error/Intern.h}.
*/
class ErrorInternNotYetImpl: public ErrorIntern
{
  public:
    /// default constructor
    ErrorInternNotYetImpl()
	: ErrorIntern("not yet implemented") {}
    /// constructor
    ErrorInternNotYetImpl(const string& m)
	: ErrorIntern(m + ": not yet implemented") {}
    /// copy constructor
    ErrorInternNotYetImpl(const ErrorIntern& src)
	: ErrorIntern(src) {}
    /// assignment operator:
    const ErrorInternNotYetImpl& operator=(const ErrorInternNotYetImpl &src)
	{ if (&src != this) ErrorIntern::operator=(src); return *this; }
    /// destructor:
    virtual ~ErrorInternNotYetImpl ()  throw () {}
};


END_NAMESPACE

#endif // AH_ERROR_INTERN_H
//**********************************************************************
//*			     E N D   O F   F I L E                     *
//**********************************************************************


