//---------------------------------------------------------------------------
// Copyright 1999 Andreas Huennebeck
//
// Licensed under the terms of the GNU General Public License.
// ABSOLUTELY NO WARRANTY. See the file 'COPYING' in this distribution.
//
// $Source: /home/ah/CvsTree/daten/src/include/AH/IO/Riff/WaveFileCached.h,v $
// $Id: WaveFileCached.h,v 1.3 2004/03/21 16:17:17 ah Exp $
//
// Description: 
//
//---------------------------------------------------------------------------

#ifndef AH_IO_RIFF_WAVE_FILE_CACHED_H		// prevent multiple includes
#define AH_IO_RIFF_WAVE_FILE_CACHED_H

// --- forward declarations ---

// --- necessary includes ---

#include <AH/Config/Platform.h>
#include <AH/Config/Types.h>
#include <AH/IO/Riff/WaveFile.h>
USING_NAMESPACE(AH)

// --- types and classes ---

BEGIN_NAMESPACE(AH)

// represents a cached RIFF WAVE file
class IORiffWaveFileCached: public IORiffWaveFile
{
 public:
    //-------------------
    // con-/destructors:
    //-------------------
    
    /// constructor for input WAV file 
    IORiffWaveFileCached
    (
	/// name of output file
	const char* name,
	/// size of cache in number of samples
	uint32 samSize,
	/// set to true if we must read from a pipe
	bool isPipe,
	/// verbose level
	int verbose = 0
    );

    /// constructor for input file (WAV, MP3, Ogg, ...) 
    IORiffWaveFileCached
    (
	/// name of output file
	const char* name,
	/// size of cache in number of samples
	uint32 samSize,
	/// verbose level
	int verbose = 0
    );

    /// constructor for output WAV file 
    IORiffWaveFileCached
    (
	/// name of output file
	const char* name,
	/// number of channels
	uint16 channel_num,
	/// size of sample in bits
	uint16 sample_size,
	/// sample rate in Hz
	uint32 sample_rate,
	/// number of samples per channel
	uint32 sample_num = 0,
	/// size of cache in number of samples
	uint32 samSize = 44100,
	/// verbose level
	int verbose = 0
    );

    /// destructor
    virtual ~IORiffWaveFileCached();

    //-----------------------
    // read/write functions:
    //-----------------------

    /// read PCM sample from wave file
    int32 readSample(int32* value, uint32 samNum, uint16 chan);

    // write PCM sample into wave file
    void writeSample(int32 value, uint32 samNum, uint16 chan);

 private:
    int32  readCache(uint32 startSamNum);
    void   writeCache();

    int32* cache;       // the cache
    int32 cacheSamNum;  // number of samples in cache
    uint32 cacheStart;  // number of first sample in buffer
    uint32 cacheEnd;    // number of last sample in buffer
    bool  isOutput;     // true if output file
};

END_NAMESPACE

#endif // !AH_IO_RIFF_WAVE_FILE_CACHED_H
