//---------------------------------------------------------------------------
// Copyright 1998 Andreas Huennebeck
//
// Licensed under the terms of the GNU General Public License.
// ABSOLUTELY NO WARRANTY. See the file `COPYING' in this distribution.
//
// $Source: /home/ah/CvsTree/daten/src/include/AH/IO/TimeStamp.h,v $
// $Id: 
//
// Description: declaration of class AH::IOTimeStamp
//
//---------------------------------------------------------------------------

#ifndef AH_IO_TIMESTAMP_H		// prevent multiple includes
#define AH_IO_TIMESTAMP_H

// --- forward declarations ---

// --- necessary includes ---

#include <AH/Config/Platform.h>
USING_NAMESPACE(AH)

#include <sys/times.h>
//#include <ctime>
#include <string>
USING_NAMESPACE(std)

// --- types and classes ---

BEGIN_NAMESPACE(AH)

/** represents a time stamp (for profiling). */
class IOTimeStamp
{
 public:
    /** default constructor. */
    IOTimeStamp() { update(); }

    /// copy constructor
    IOTimeStamp(const IOTimeStamp& ts)
	: stamp(ts.stamp) {}

    /** update current time stamp. */
    void update() { (void)times(&stamp); }

    /** return user time in clocks. */
    unsigned int getUserClocks() const 
	{ return stamp.tms_utime; }

    /** return system time in clocks. */
    unsigned int getSystemClocks() const 
	{ return stamp.tms_stime; }

    /** return user time in seconds. */
    double getUserTime() const 
	{ return (double)stamp.tms_utime / clock_tick; }

    /** return system time in seconds. */
    double getSystemTime() const 
	{ return (double)stamp.tms_stime / clock_tick; }

    /** return user time as string. */
    std::string getUserTimeString() const
	{ return timeString("User", getUserTime()); }

    /** return system time as string. */
    std::string getSystemTimeString() const
	{ return timeString("System", getSystemTime()); }

    /** return user and system time as string. */
    std::string getTimeString() const
	{ return getUserTimeString() + " " + getSystemTimeString(); }

    IOTimeStamp operator+ (const IOTimeStamp &ts1);
    IOTimeStamp operator- (const IOTimeStamp &ts1);
    IOTimeStamp& operator= (const IOTimeStamp &ts1);
    friend bool operator== (const IOTimeStamp &ts1, const IOTimeStamp &ts2);
    friend bool operator!= (const IOTimeStamp &ts1, const IOTimeStamp &ts2);

 private:
    /** constructor for operators. */
    IOTimeStamp(const struct tms& ts) : stamp(ts) {}
    /** return time as string. */
    static std::string timeString(const std::string& name, double t);

    struct tms stamp;
    static int clock_tick;
};



END_NAMESPACE

#endif // !AH_IO_TIMESTAMP_H

