//---------------------------------------------------------------------------
// Copyright 1999 Andreas Huennebeck
//
// Licensed under the terms of the GNU General Public License.
// ABSOLUTELY NO WARRANTY. See the file `COPYING' in this distribution.
//
// $Source: /home/ah/CvsTree/daten/src/libAHio/Plot.c,v $
// $Id: 
//
// Description: 
//
//---------------------------------------------------------------------------

static const char rcsid[] = "$Id: Plot.c,v 1.4 2004/04/20 22:26:22 ah Exp $ (c) 1999 Andreas Huennebeck";

// --- necessary includes ---

#include <AH/IO/Plot.h>
#include <AH/Error/Sys.h>
USING_NAMESPACE(AH)

BEGIN_NAMESPACE(AH)

// constructor: start gnuplot
IOPlot::IOPlot()
    : fp(popen("gnuplot","w"))
{
    if (!fp) throw ErrorSys();
}

// constructor: start gnuplot
IOPlot::IOPlot(const string& plotprog)
    : fp(popen(plotprog.c_str(),"w"))
{
    if (!fp) throw ErrorSys();
}
 
// destructor: exit gnuplot
IOPlot::~IOPlot()
{
    if (fp)
    {
	exec("quit");
	(void)pclose(fp);
    }
}

// send command to gnuplot
void IOPlot::exec(const string& cmd) 
{
    if (fp) 
    {
	if (-1 == fprintf(fp, "%s\n", cmd.c_str())) throw ErrorSys();
	flush();
    }
}

// send multiple commands to gnuplot
void IOPlot::exec(const vector<string>& cmds)
{
    if (fp) 
    {
	for (unsigned int i = 0; i < cmds.size(); ++i)
	{
	    if (-1 == fprintf(fp, "%s\n", cmds[i].c_str()))
		throw ErrorSys();
	}
	flush();
    }
}

// send PLOT command to gnuplot to plot data from a file
void IOPlot::plot(const string& file, const string& options) 
{
    exec("plot \"" + file + "\" " + options);
}

// send command to gnuplot
void IOPlot::plot(const string& options) 
{
    exec("plot " + options);
}

// send PLOT command to gnuplot to plot data directly
void IOPlot::plot(const vector<string>& data, const string& options)
{
    exec("plot \"-\" " + options);
    for (unsigned int i = 0; i < data.size(); ++i)
	exec(data[i]);
    exec("e");
}

// set X range (horizontal axis)
void IOPlot::setXrange(double from, double to)
{
    char buf[80];
    (void)sprintf(buf, "set xrange [%f:%f]", from, to);
    exec(buf);
}

// set Y range (vertical axis)
void IOPlot::setYrange(double from, double to)
{
    char buf[80];
    (void)sprintf(buf, "set yrange [%f:%f]", from, to);
    exec(buf);
}

// flush command pipe
void IOPlot::flush()
{
    if (-1 == fflush(fp)) throw ErrorSys();
}


END_NAMESPACE
