//---------------------------------------------------------------------------
// Copyright 2000 Andreas Huennebeck
//
// Licensed under the terms of the GNU General Public License.
// ABSOLUTELY NO WARRANTY. See the file `COPYING' in this distribution.
//
// $Source: /home/ah/CvsTree/daten/src/mpegtools/fileset.c,v $
// $Id: fileset.c,v 1.2 2000/10/11 22:14:38 ah Exp $ 
//
// Description: cut a pice out of a mp3 file into a new mp3 file
//
//---------------------------------------------------------------------------

static const char rcsid[] = "$Id: fileset.c,v 1.2 2000/10/11 22:14:38 ah Exp $ (c) 2000 Andreas Huennebeck";

// --- necessary includes ---
#include <AH/Config/Platform.h> // always the first include
#include <AH/Config/Types.h>
USING_NAMESPACE(AH)

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <errno.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h> 
#include <iostream>
#include <fstream>
#include <vector>
#include <string>
USING_NAMESPACE(std)

#include <AH/Error/Class.h>
#include <AH/Error/Basic.h>
#include <AH/STL/String.h>
#include "fileset.h"

USING_NAMESPACE(AH)

// --- local constants ---

// --- local variables ---

// --- local classes ---

// add new file name
void FileSettings::addFileName(const string& name)
{
    fileName.push_back(name);
    if (frameRange.size() < fileName.size()) 
	frameRange.push_back("");
    if (timeRange.size() < fileName.size()) 
	timeRange.push_back("");
}


// add frame settings
void FileSettings::addFrameRange(const string& sr)
{
    if (frameRange.size() > fileName.size())
	frameRange[frameRange.size() - 1] = sr;
    else
	frameRange.push_back(sr);
}


// add time settings
void FileSettings::addTimeRange(const string& sr)
{
    if (timeRange.size() > fileName.size())
	timeRange[timeRange.size() - 1] = sr;
    else
	timeRange.push_back(sr);
}


// get number of entries
unsigned int FileSettings::getNum() const 
{
    return fileName.size(); 
}


// get specified filename
const string& FileSettings::getFileName(unsigned int i) const
{
    if (i < fileName.size()) return fileName[i]; 
    return empty;
}


// get specified frame range
const string& FileSettings::getFrameRange(unsigned int i) const
{
    if (i < frameRange.size()) return frameRange[i]; 
    return empty;
}

// get specified frame range
void FileSettings::getFrameRange(unsigned int i, int& f1, int& f2) const
{
    f1 = f2 = -1; // default

    string range = getFrameRange(i);
    STLStringDelSurround(range);
    if (range == "") return;
    
    vector<string> token;
    STLStringToken(range, token, "-");
    switch (token.size())
    {
    default:
    case 0: return;
    case 1:
	if ('-' == range[0]) f2 = atoi(token[0].c_str());
	else		     f1 = atoi(token[0].c_str());
	return;
    case 2: 
	f1 = atoi(token[0].c_str());
	f2 = atoi(token[1].c_str());
	return;
    }
}


// get specified time range
const string& FileSettings::getTimeRange(unsigned int i) const
{
    if (i < timeRange.size()) return timeRange[i]; 
    return empty;
}


static double convStr2Time(const string& s)
{
    vector<string> token;
    STLStringToken(s, token, ":");
    switch (token.size())
    {
    default:
    case 0: return -1;
    case 1: return atof(s.c_str());
    case 2: 
        {
	    int min = atoi(token[0].c_str());
	    double sec = atof(token[1].c_str());
	    return (double)(60 * min) + sec;
	}
    }
}


// get specified time range
void FileSettings::getTimeRange(unsigned int i, double& t1, double& t2) const
{
    t1 = t2 = -1; // default

    string range = getTimeRange(i);
    STLStringDelSurround(range);
    if (range == "") return;

    vector<string> token;
    STLStringToken(range, token, "-");
    switch (token.size())
    {
    default:
    case 0: return;
    case 1:
	if ('-' == range[0]) t2 = convStr2Time(token[0].c_str());
	else		     t1 = convStr2Time(token[0].c_str());
	return;
    case 2: 
	t1 = convStr2Time(token[0].c_str());
	t2 = convStr2Time(token[1].c_str());
	return;
    }
}


// --- end of file ---

















